/**  
 *  BookReporter - Generate usage reports from text files
 *  Copyright (C) 2011 Skye Book
 *  
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *  
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *  
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package net.skyebook.bookreporter;

import java.io.File;
import java.io.IOException;

import net.skyebook.bookreporter.export.DictionaryExporter;
import net.skyebook.bookreporter.export.OneWordPerLineExporter;

import org.apache.commons.cli.CommandLine;
import org.apache.commons.cli.CommandLineParser;
import org.apache.commons.cli.HelpFormatter;
import org.apache.commons.cli.Option;
import org.apache.commons.cli.Options;
import org.apache.commons.cli.ParseException;
import org.apache.commons.cli.PosixParser;

/**
 * @author Skye Book
 *
 */
public class BookReporter {
	
	private static Options options;

	/**
	 * @param args
	 * @throws ParseException 
	 */
	public static void main(String[] args) throws ParseException {
		// Setup Apache Commons CLI
		optionsSetup();
		
		CommandLineParser parser = new PosixParser();
		CommandLine cmd = parser.parse(options, args);
		
		
		// run me
		if(args.length==0){
			showHelp();
		}
		else{
			// Use the last given argument as the file
			File text = new File(args[args.length-1]);
			try {
				long startTime = System.currentTimeMillis();
				BookDictionary dictionary = DictionaryGenerator.generateDictionary(text);
				System.out.println("Dictionary generation took " + (System.currentTimeMillis()-startTime) +"ms");
				System.out.println(dictionary.size() + " words found");
				DictionaryExporter exporter = new OneWordPerLineExporter(new File("results.txt"));
				exporter.export(dictionary);
			} catch (IOException e) {
				System.out.println("File could not be found or read: " + text.toString());
			}
		}
	}
	
	private static void showHelp(){
		HelpFormatter help = new HelpFormatter();
		help.printHelp("Give this application a file", options);
	}
	
	
	private static void optionsSetup(){
		options = new Options();

		Option help = new Option("help", "Print this help menu");

		options.addOption(help);
	}

}
