/**  
 *  BookReporter - Generate usage reports from text files
 *  Copyright (C) 2011 Skye Book
 *  
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *  
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *  
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package net.skyebook.bookreporter;

import java.io.BufferedReader;
import java.io.File;
import java.io.FileReader;
import java.io.IOException;
import java.util.ArrayList;
import java.util.List;

/**
 * @author Skye Book
 *
 */
public class DictionaryGenerator {


	private static List<String> ignoreList;

	private static final String alphaNumericRegex = "[0-9A-Za-z]";

	// I should get more of these
	static{
		ignoreList = new ArrayList<String>();
		ignoreList.add("a");
		ignoreList.add("an");
		ignoreList.add("and");
		ignoreList.add("the");
		ignoreList.add("of");
		ignoreList.add("or");
	}

	private static String clearWord(String sentWord){

		String word = sentWord;

		for(int i=0; i<word.length(); i++){
			// if this isn't a valid character, remove it
			//System.out.println(((Character)word.charAt(i)).toString());
			
			String charString = ((Character)word.charAt(i)).toString();
			if(charString.equals("(")
					||charString.equals(")")
					||charString.equals("?")
					||charString.equals("[")
					||charString.equals("]")){
				charString = new String("\\"+charString);
			}
			
			if(!charString.matches(alphaNumericRegex)){
				word = word.replaceFirst(charString, "");
			}
		}

		return word;
	}


	public static BookDictionary generateDictionary(File text) throws IOException{
		BookDictionary dictionary = new BookDictionary();

		BufferedReader reader = new BufferedReader(new FileReader(text));

		String lastLine=null;
		String currentLine=null;

		while(reader.ready()){
			currentLine=reader.readLine();

			// check if this is a two part word
			if(lastLine!=null){
				// TODO
			}

			String[] words = currentLine.split(" ");

			for(int i=0; i<words.length; i++){
				String word = words[i];
				if(!word.matches(alphaNumericRegex)){
					word = clearWord(word);
				}
				
				
				boolean ignoreMe = false;
				for(String ignore : ignoreList){
					if(word.equals(ignore)){
						ignoreMe=true;
						continue;
					}
				}
				if(ignoreMe) continue;
				
				// Add to dictionary
				dictionary.put(word);
			}
			
			lastLine=currentLine;
		}

		return dictionary;
	}

}
